@@ -8,7 +8,12 @@ from kdp_connector.connectors.query import QueryApi
 from kdp_connector.connectors.index_management import IndexManagementApi
 from kdp_connector.connectors.upload import UploadApi
 from kdp_connector.connectors.Storage import StorageApi
+from kdp_connector.connectors.audit_log import AuditLogApi
+from kdp_connector.connectors.audit_log_configs import AuditLogConfigsApi
 from kdp_api.models import SecurityLabelInfoParams
+from kdp_api.model.audit_log_configuration_paginator import AuditLogConfigurationPaginator
+from kdp_api.model.audit_log_configuration import AuditLogConfiguration
+from kdp_api.model.audit_log_paginator import AuditLogPaginator
 from pandas import DataFrame
 
 class KdpConn(object):
@@ -161,6 +166,28 @@ class KdpConn(object):
         return query_api.post_lucene_query(config, dataset_id=dataset_id, expression=expression, limit=limit,
                                            offset=offset)
 
+
+    def post_document_lucene_query(self, dataset_id: str, jwt: str, expression: str = '', limit: int = 5, offset: int = 0):
+        """This method will be used to query document data in KDP datasets using the lucene syntax
+
+            :param str dataset_id: ID of the KDP dataset where the data will queried
+            :param str jwt: JWT token
+            :param str expression: Lucene style query expression ex. name: John
+            :param int limit: max number of results in the response.
+            :param int offset: how many records to skip before returning first record.
+
+            :returns: QueryDocumentLuceneResponse object contains records matching query expression
+
+            :rtype: QueryDocumentLuceneResponse
+        """
+        query_api = QueryApi()
+        config = self.create_configuration(jwt)
+        return query_api.post_document_lucene_query(config, dataset_id=dataset_id, expression=expression, limit=limit,
+                                           offset=offset)
+
+
+
+
     # READ
     def read_dataset_to_dictionary_list(self, dataset_id: str, jwt: str,
                                         starting_record_id: str = '', batch_size: int = 100000):
@@ -458,3 +485,60 @@ class KdpConn(object):
         kdp_api = KdpApi()
         config = self.create_configuration(jwt)
         return kdp_api.delete_user(config, user_id)
+
+
+
+    # audit log configs
+    def get_audit_log_configs(self, jwt: str, keep_forever:bool = None, workspace_id:str = None,
+        limit:int = 10, skip:int=0, sort:object=None, filter:object=None) -> AuditLogConfigurationPaginator:
+        """This method returns a AuditLogConfigurationPaginator object which contains list of AuditLogConfiguration objects.
+
+            :param Configuration config: Connection configuration
+            :param bool keep_forever: filter on keepForever flag.
+            :param str workspace_id: filter on workspace ID.
+            :param int limit: max number of results in the response.
+            :param int skip: how many records to skip before returning first record.
+            :param object sort: sorting configuration
+            :param object filter: additional filtering configuration
+            :returns: AuditLogConfigurationPaginator object
+
+            :rtype: AuditLogConfigurationPaginator
+        """
+        config = self.create_configuration(jwt)
+        audit_log_configs_api = AuditLogConfigsApi(configuration=config)
+        return audit_log_configs_api.get_audit_log_configs(config=config, keep_forever=keep_forever, workspace_id=workspace_id,
+            limit=limit, skip=skip, sort=sort, filter=filter)
+
+
+
+    def patch_audit_log_configs(self, jwt: str, id:str, keep_forever:bool, age_in_days: int) -> AuditLogConfiguration:
+        """This method updates AuditLogConfiguration object.
+
+            :param Configuration config: Connection configuration
+            :param str id: audit log config id
+            :param bool keep_forever: keepForever flag.
+            :param int age_in_days: number of days to keep the records if keep_forever flag is false.
+            :returns: AuditLogConfiguration object after the update.
+
+            :rtype: AuditLogConfiguration
+        """
+        config = self.create_configuration(jwt)
+        audit_log_configs_api = AuditLogConfigsApi(configuration=config)
+        return audit_log_configs_api.patch_audit_log_configs(config=config, id=id, keep_forever=keep_forever, age_in_days=age_in_days);
+
+
+    # audit log
+    def post_audit_log_query(self, jwt: str, dataset_id: str, expression: str, limit: int = 5, offset: int = 0) -> AuditLogPaginator:
+        """This method will be used to query data in KDP datasets using the lucene syntax
+
+            :param str dataset_id: audit log dataset id
+            :param str expression: Lucene style query expression ex. name: John
+            :param int limit: max number of results in the response.
+            :param int offset: how many records to skip before returning first record.
+            :returns: AuditLogPaginator object which contains audit log records matching query expression
+
+            :rtype: AuditLogPaginator
+        """
+        config = self.create_configuration(jwt)
+        audit_log_api = AuditLogApi(configuration=config)
+        return audit_log_api.post_audit_log_query(config=config, dataset_id=dataset_id, expression=expression, limit=limit, offset=offset)
